@@ -113,7 +113,7 @@ import Language.Haskell.TH.Syntax (Lift (lift), Q, Exp, Loc (..), qLocation)
 import Data.Functor ((<$>))
 import Data.Monoid (Monoid)
 
-import Control.Applicative (Applicative (..), WrappedMonad(..))
+import Control.Applicative (Alternative (..), Applicative (..), WrappedMonad(..))
 import Control.Concurrent.Chan (Chan(),writeChan,readChan)
 import Control.Concurrent.STM
 import Control.Concurrent.STM.TBChan
@@ -137,9 +137,11 @@ import Control.Monad.Catch (MonadThrow (..), MonadCatch (..), MonadMask (..)
                            )
 
 import Control.Monad.Trans.Identity ( IdentityT)
-import Control.Monad.Trans.List     ( ListT    )
 import Control.Monad.Trans.Maybe    ( MaybeT   )
+#if !MIN_VERSION_transformers(0, 6, 0)
+import Control.Monad.Trans.List     ( ListT    )
 import Control.Monad.Trans.Error    ( ErrorT, Error)
+#endif
 import Control.Monad.Trans.Except   ( ExceptT  )
 
 import Control.Monad.Trans.Reader   ( ReaderT  )
@@ -249,9 +251,11 @@ instance MonadLogger (Lazy.ST s) where monadLoggerLog _ _ _ = return ()
 
 #define DEF monadLoggerLog a b c d = Trans.lift $ monadLoggerLog a b c d
 instance MonadLogger m => MonadLogger (IdentityT m) where DEF
+#if !MIN_VERSION_transformers(0, 6, 0)
 instance MonadLogger m => MonadLogger (ListT m) where DEF
-instance MonadLogger m => MonadLogger (MaybeT m) where DEF
 instance (MonadLogger m, Error e) => MonadLogger (ErrorT e m) where DEF
+#endif
+instance MonadLogger m => MonadLogger (MaybeT m) where DEF
 instance MonadLogger m => MonadLogger (ExceptT e m) where DEF
 instance MonadLogger m => MonadLogger (ReaderT r m) where DEF
 instance MonadLogger m => MonadLogger (ContT r m) where DEF
@@ -267,9 +271,11 @@ instance (MonadLogger m, Monoid w) => MonadLogger (Strict.RWST r w s m) where DE
 #undef DEF
 
 instance MonadLoggerIO m => MonadLoggerIO (IdentityT m)
+#if !MIN_VERSION_transformers(0, 6, 0)
 instance MonadLoggerIO m => MonadLoggerIO (ListT m)
-instance MonadLoggerIO m => MonadLoggerIO (MaybeT m)
 instance (MonadLoggerIO m, Error e) => MonadLoggerIO (ErrorT e m)
+#endif
+instance MonadLoggerIO m => MonadLoggerIO (MaybeT m)
 instance MonadLoggerIO m => MonadLoggerIO (ExceptT e m)
 instance MonadLoggerIO m => MonadLoggerIO (ReaderT r m)
 instance MonadLoggerIO m => MonadLoggerIO (ContT r m)
@@ -383,7 +389,10 @@ logOtherS = [|\src level msg -> monadLoggerLog $(qLocation >>= liftLoc) src (Lev
 --
 -- @since 0.2.4
 newtype NoLoggingT m a = NoLoggingT { runNoLoggingT :: m a }
-  deriving (Functor, Applicative, Monad, MonadIO, MonadThrow, MonadCatch, MonadMask, MonadActive, MonadBase b)
+  deriving (
+    Functor, Applicative, Monad, MonadIO, MonadThrow, MonadCatch, MonadMask, MonadActive, MonadBase b
+    , Alternative -- ^ @since 0.3.40
+    )
 
 -- For some reason GND is a fool on GHC 7.10 and older, we have to help it by providing the context explicitly.
 deriving instance MonadResource m => MonadResource (NoLoggingT m)
@@ -592,6 +601,11 @@ instance Applicative m => Applicative (LoggingT m) where
     {-# INLINE (<*>) #-}
 #endif
 
+-- | @since 0.3.40
+instance (Alternative m) => Alternative (LoggingT m) where
+  empty = LoggingT (const empty)
+  LoggingT x <|> LoggingT y = LoggingT (\f -> x f <|> y f)
+
 #if MIN_VERSION_base(4, 9, 0)
 -- | @since 0.3.30
 instance (Fail.MonadFail m) => Fail.MonadFail (LoggingT m) where
